﻿using AzureBakery.Production.Model;
using Microsoft.ServiceBus;
using Microsoft.ServiceBus.Messaging;
using System;
using System.Collections.Generic;
using System.Linq;
using System.Web;

namespace ManagementWebApi.Services
{
    public class MessagingService
    {
        private readonly TopicClient _topicClient = null;
        private const string _topicName = "Order";
        private const string _subscriptionName = "ManagementWebApiSubscription";

        public MessagingService()
        {
            this._topicClient = TopicClient.Create(_topicName);
        }

        public void CreateSubscription()
        {
            var namespaceManager = NamespaceManager.Create();

            // Look for topic
            if (!namespaceManager.TopicExists(_topicName))
                return;

            var topic = namespaceManager.GetTopicAsync(_topicName);

            if (!namespaceManager.SubscriptionExists(_topicName, _subscriptionName))
            {
                namespaceManager.CreateSubscriptionAsync(_topicName, _subscriptionName);
            }
        }

        public void UpdateOrder(Order order, int retries = 0)
        {
            var salesOrder = new AzureBakery.Sales.Model.Order()
            {
                Id = order.Id,
                Status = (AzureBakery.Sales.Model.OrderStatus)order.Status,
                Reference = order.Reference
            };

            var message = new BrokeredMessage(salesOrder);

            message.Properties["Status"] = "ReadyForDispatch";
            message.MessageId = Guid.NewGuid().ToString();

            this.SendMessage(message, retries);
        }

        private void SendMessage(BrokeredMessage message, int retries = 0)
        {
            int retry = 0;

            while (true)
            {
                try
                {
                    this._topicClient.Send(message);
                    break;
                }
                catch (MessagingException e)
                {
                    if (!e.IsTransient)
                        throw;
                    else
                        retry++;
                }

                if (retry > retries)
                    break;

                // Back-off for retry
                System.Threading.Thread.Sleep(3000);
            }
        }
    }
}