﻿using AzureBakery.Production.ManagementApplication.Services.Interfaces;
using AzureBakery.Production.Model;
using Microsoft.IdentityModel.Clients.ActiveDirectory;
using System;
using System.Collections.Generic;
using System.Configuration;
using System.Diagnostics;
using System.Net;
using System.Net.Http;
using System.Threading.Tasks;
using Newtonsoft.Json;

namespace AzureBakery.Production.ManagementApplication.Services
{
    public class DataService : AzureAdAuthBase, IDataService
    {
        public async Task<IEnumerable<Order>> GetOrders()
        {
            return await this.GetData<IEnumerable<Order>>("orders");
        }

        public async Task<IEnumerable<Batch>> GetBatches()
        {
            return await this.GetData<IEnumerable<Batch>>("batches");
        }

        private async Task<T> GetData<T>(string action)
        {
            if (!base.Login())
                return default(T);

            // Call Web API
            var authHeader = this.Token.CreateAuthorizationHeader();
            var client = new HttpClient();
            var uri = string.Format("{0}{1}", this.ServiceUri, string.Format("api/{0}", action));
            var request = new HttpRequestMessage(HttpMethod.Get, uri);
            request.Headers.TryAddWithoutValidation("Authorization", authHeader);

            // Get response
            var response = await client.SendAsync(request);
            var responseString = await response.Content.ReadAsStringAsync();

            // Deserialize JSON
            var data = await Task.Factory.StartNew(() => JsonConvert.DeserializeObject<T>(responseString));

            return data;
        }
    }
}
