﻿using System.Threading.Tasks;
using CustomerMobileService.Models;
using Microsoft.ServiceBus.Notifications;
using Microsoft.WindowsAzure.Mobile.Service;
using Microsoft.WindowsAzure.Mobile.Service.Security;
using Microsoft.WindowsAzure.Mobile.Service.Notifications;
using System.Web.Http;
using System.Data.Entity;
using AzureBakery.Sales.Model;
using System;

namespace CustomerMobileService.Controllers
{
    [AuthorizeLevel(AuthorizationLevel.Admin)]
    public class NotificationController : ApiController
    {
        public ApiServices Services { get; set; }

        private readonly CustomerMobileServiceContext _ctx = new CustomerMobileServiceContext();

        // GET api/Notification
        public string Get()
        {
            Services.Log.Info("Hello from custom controller!");
            return "Hello";
        }

        [HttpPost]
        [Route("api/Notification/PostOrderUpdate")]
        public async Task PostOrderUpdate([FromBody]dynamic data)
        {
            Services.Log.Info("NotificationController.PostOrderUpdate - Started");

            var orderId = (int)data.orderId;

            // Get order
            var order = await this._ctx.Orders.FindAsync(orderId);

            if (order == null)
            {
                Services.Log.Warn(string.Format("NotificationController.PostOrderUpdate - Order does not exist {0}", orderId));
                return;
            }

            var text1 = string.Format("Azure Bakery Order: {0}", order.Reference);
            var text2 = string.Format("Status: {0}", order.Status);

            var backTitle = string.Format("Order: {0}", order.Reference);
            var backContent = string.Format("Status: {0}", order.Status);

            var tags = new string[] {order.Customer.PushHandle};

            await this.SendToast(text1, text2, tags);
            await this.SendTile(backTitle, backContent, tags);

            Services.Log.Info("NotificationController.PostOrderUpdate - Completed");
        }

        [HttpPost]
        [Route("api/Notification/PostProductNews")]
        public async Task PostProductNews([FromBody]dynamic data)
        {
            Services.Log.Info("NotificationController.PostProductNews - Started");

            var productId = (int)data.productId;

            // Get order
            var product = await this._ctx.Products.FindAsync(productId);

            if (product == null)
            {
                Services.Log.Warn(string.Format("NotificationController.PostProductNews - Product does not exist {0}", productId));
                return;
            }

            var text1 = "Azure Bakery Product News";
            var text2 = string.Format("{0} now available!", product.Name);

            var backTitle = "Product News";
            var backContent = string.Format("{0} now available!", product.Name);

            var tags = new string[] { "news" };

            await this.SendToast(text1, text2, tags);
            await this.SendTile(backTitle, backContent, tags);

            Services.Log.Info("NotificationController.PostProductNews - Completed");
        }

        private async Task SendToast(string text1, string text2, string[] tags)
        {
            try
            {
                // Create toast
                var toast = new Toast()
                {
                    Text1 = text1,
                    Text2 = text2
                };

                // Add to message
                var msg = new MpnsPushMessage(toast);
  
                // Send to notifications hub
                var result = await new PushClient(Services).SendAsync(msg,tags);
            }
            catch (Exception ex)
            {
                Services.Log.Error(ex);
            }
        }

        private async Task SendTile(string backTitle, string backContent, string[] tags)
        {
            try
            {
                // Create tile
                var tile = new FlipTile()
                {
                    Title = "Azure Bakery",
                    BackTitle = backTitle,
                    BackContent = backContent
                };

                // Add to message
                var msg = new MpnsPushMessage(tile);

                // Send to notifications hub
                var result = await new PushClient(Services).SendAsync(msg, tags);
            }
            catch (Exception ex)
            {
                Services.Log.Error(ex);
            }
        }
    }
}
