﻿using CustomerPhoneApp.Helpers;
using Microsoft.WindowsAzure.MobileServices;
using System;
using System.Threading.Tasks;

namespace CustomerPhoneApp.DataServices
{
    public abstract class DataServiceBase
    {
        private const string USER_ID = "USER_ID";
        private const string USER_TOKEN = "USER_TOKEN";

        #if DEBUG 
        // Our DEBUG MobileServiceClient instance with Url and application key set
        protected readonly static MobileServiceClient _mobileService = new MobileServiceClient(
            "http://localhost:61021",
            "4E2D5547-FEC4-4870-8060-CB1736D4529A"
            );
        #else
        // Our MobileServiceClient instance with Url and application key set
        protected readonly static MobileServiceClient _mobileService = new MobileServiceClient(
            "http://azurebakerycustomer.azure-mobile.net/",
            "PopNgBgUnnYsutDBIsHzNziyUCKbyE67"
            );
        #endif

        protected static MobileServiceAuthenticationProvider _provider = MobileServiceAuthenticationProvider.Twitter;

        protected async Task<T> ExecuteAuthenticated<T>(Func<Task<T>> t, int retries = 1)
        {
            int retry = 0;
            T retVal = default(T);

            while (retry < retries)
            {
                // If we have no current user, login
                if (_mobileService.CurrentUser == null)
                {
                    // If login fails return default
                    if (!await Login())
                        return retVal;
                }

                // Try and execute task
                try
                {
                    retVal = await t();
                    break;
                }
                catch (InvalidOperationException ioex)
                {
                    // If task has failed because it was unauthorised try again
                    if (ioex.Message == "Error: Unauthorized")
                    {
                        _mobileService.CurrentUser = null;
                    }

                    retry++;
                }
            }

            return retVal;
        }

        protected async Task ExecuteAuthenticated(Func<Task> t, int retries = 1)
        {
            int retry = 0;

            while (retry < retries)
            {
                // If we have no current user, login
                if (_mobileService.CurrentUser == null)
                {
                    // If login fails return
                    if (!await Login())
                        return;
                }

                // Try and execute task
                try
                {
                    await t();
                    break;
                }
                catch (InvalidOperationException ioex)
                {
                    // If task has failed because it was unauthorised try again
                    if (ioex.Message == "Error: Unauthorized")
                    {
                        _mobileService.CurrentUser = null;
                    }

                    retry++;
                }
            }
        }

        public static bool HasUserLoggedIn()
        {
            var userId = StorageHelper.GetSetting<string>(USER_ID, null);
            var userToken = StorageHelper.GetSetting<string>(USER_TOKEN, null);

            if (userId == null || userToken == null)
                return false;

            return true;
        }

        public static async Task<bool> Login()
        {
            // First have a look and see if we have the user's token
            var userId = StorageHelper.GetSetting<string>(USER_ID, null);
            var userToken = StorageHelper.GetSetting<string>(USER_TOKEN, null);

            bool success = true;

            if (userId != null && userToken != null)
            {
                // Create user and apply to client
                var user = new MobileServiceUser(userId);
                user.MobileServiceAuthenticationToken = userToken;
                _mobileService.CurrentUser = user;
            }
            else
            {
                try
                {
                    // Login
                    var user = await _mobileService.LoginAsync(_provider);

                    // Store credentials
                    StorageHelper.StoreSetting(USER_ID, user.UserId, true);
                    StorageHelper.StoreSetting(USER_TOKEN, user.MobileServiceAuthenticationToken, true);
                }
                catch (InvalidOperationException)
                {
                    // Something has gone wrong, most likely user cancelled by backing-out
                    success = false;
                }
            }

            return success;
        }


        public static void Logout()
        {
            _mobileService.Logout();

            // Clear credentials
            StorageHelper.StoreSetting(USER_ID, null, true);
            StorageHelper.StoreSetting(USER_TOKEN, null, true);
        }
    }
}
