using System.Collections.ObjectModel;
using AzureBakery.Sales.Model;
using CustomerPhoneApp.DataServices;
using CustomerPhoneApp.Helpers;
using GalaSoft.MvvmLight;
using System.Threading.Tasks;
using GalaSoft.MvvmLight.Command;
using Microsoft.Phone.Shell;

namespace CustomerPhoneApp.ViewModel
{
    /// <summary>
    /// This class contains properties that the main View can data bind to.
    /// <para>
    /// Use the <strong>mvvminpc</strong> snippet to add bindable properties to this ViewModel.
    /// </para>
    /// <para>
    /// You can also use Blend to data bind with the tool's support.
    /// </para>
    /// <para>
    /// See http://www.galasoft.ch/mvvm
    /// </para>
    /// </summary>
    public class MainViewModel : ViewModelBase
    {
        private readonly IDataService _dataService;

        private ObservableCollection<Order> _orders = new ObservableCollection<Order>();
        private RelayCommand _initializeCommand;

        public ObservableCollection<Order> Orders
        {
            get { return this._orders; }
        }

        public RelayCommand InitializeCommand
        {
            get
            {
                if (this._initializeCommand == null)
                    this._initializeCommand = new RelayCommand(this.Initialize);
                return this._initializeCommand;
            }
        }

        /// <summary>
        /// Initializes a new instance of the MainViewModel class.
        /// </summary>
        public MainViewModel(IDataService dataService)
        {
            if (IsInDesignMode)
            {
                // Code runs in Blend --> create design time data.
            }
            else
            {
                this._dataService = dataService;
            }
        }

        public async void Initialize()
        {
            await this.LoadOrders();

            if (PhoneApplicationService.Current.StartupMode == StartupMode.Launch)
                await ChannelHelper.Default.SetupChannel();
        }

        private async Task LoadOrders()
        {
            var orders = await this._dataService.GetOrders();

            foreach (var order in orders)
            {
                this._orders.Add(order);
            }
        }
    }
}