﻿using AzureBakery.Sales.CustomerWebsite.Models;
using AzureBakery.Sales.Model;
using System;
using System.Collections.Generic;
using System.Diagnostics;
using System.Linq;
using System.Web;
using System.Data.Entity;

namespace AzureBakery.Sales.CustomerWebsite.DataAccess
{
    public class OrderUoW : IDisposable
    {
        private readonly Repository<Product> _products = null;
        private readonly Repository<ApplicationUser> _users = null;
        private readonly Repository<Order> _orders = null;
        private readonly Repository<OrderItem> _orderItems = null;

        private readonly ApplicationDbContext _ctx = new ApplicationDbContext();

        public Repository<Product> Products { get { return this._products; } }
        public Repository<ApplicationUser> Users { get { return this._users; } }
        public Repository<Order> Orders { get { return this._orders; } }

        public Repository<OrderItem> OrderItems { get { return this._orderItems; } }

        public OrderUoW()
        {
            this._products = new Repository<Product>(this._ctx);
            this._users = new Repository<ApplicationUser>(this._ctx);
            this._orders = new Repository<Order>(this._ctx);
            this._orderItems = new Repository<OrderItem>(this._ctx);
        }

        public IQueryable<Order> GetCustomerOrders(string uid)
        {
            Trace.TraceInformation("OrderUoW GetCustomerOrders Start");

            IQueryable<Order> orders = null;

            try
            {
                var customer = this._ctx.Users
                    .Include(u => u.Customer)
                    .Single(u => u.Id == uid).Customer;

                // Try and find orders 
                orders = this._ctx.Orders
                    .Include(o => o.Customer)
                    .Where(o => o.Customer.Id == customer.Id)
                    .OrderByDescending(o => o.CreatedDate);
            }
            catch (Exception ex)
            {
                Trace.TraceError("OrderUoW GetCustomerOrders Exception: {0}", ex);

                throw;
            }

            Trace.TraceInformation("OrderUoW GetCustomerOrders End");

            return orders;
        }

        public Order GetOpenOrder(string uid)
        {
            Trace.TraceInformation("OrderUoW GetOpenOrder Start");

            Order order = null;

            try
            {
                var customer = this._ctx.Users
                .Include(u => u.Customer)
                .Include(u => u.Customer.Address)
                .Single(u => u.Id == uid).Customer;

                // Try and find order 
                order = this._ctx.Orders
                    .Include(o => o.Items.Select(i => i.Product))
                    .Include(o => o.Customer)
                    .SingleOrDefault(o => o.Customer.Id == customer.Id && o.Status == OrderStatus.Open);
            }
            catch (Exception ex)
            {
                Trace.TraceError("OrderUoW GetOpenOrder Exception: {0}", ex);

                throw;
            }

            Trace.TraceInformation("OrderUoW GetOpenOrder End");

            return order;
        }

        public void SaveChanges()
        {
            Trace.TraceInformation("OrderUoW Save Start");

            try
            {
                this._ctx.SaveChanges();
            }
            catch (Exception ex)
            {
                Trace.TraceError("OrderUoW Save Exception: {0}", ex);

                throw;
            }

            Trace.TraceInformation("OrderUoW Save End");
        }

        public void Dispose()
        {
            this._ctx.Dispose();
        }
    }
}