﻿using AzureBakery.Sales.Model;
using Microsoft.WindowsAzure;
using Microsoft.WindowsAzure.MobileServices;
using OrderProcessorRole.DataAccess;
using System.Dynamic;
using System.Linq;
using System.Threading.Tasks;

namespace OrderProcessorRole.Business
{
    public class OrderProcessor
    {
        private readonly ApplicationDbContext _ctx = new ApplicationDbContext();
        private readonly MobileServiceClient _mobileService;

        public OrderProcessor()
        {
            var mobileServiceUrl = CloudConfigurationManager.GetSetting("mobileServiceUrl");
            var mobileServiceKey = CloudConfigurationManager.GetSetting("mobileServiceKey");

            this._mobileService = new MobileServiceClient(mobileServiceUrl, mobileServiceKey);
        }

        public async Task Process(Order order)
        {
            // Update status
            var currentOrder = this._ctx.Orders.FirstOrDefault(o => o.Id == order.Id);

            if (currentOrder != null && currentOrder.Status != order.Status)
            {
                currentOrder.Status = order.Status;

                await this._ctx.SaveChangesAsync();

                await this.NotifyHub(order.Id);
            }
        }

        private async Task NotifyHub(int orderId)
        {
            dynamic data = new ExpandoObject();
            data.orderId = orderId;

            await this._mobileService.InvokeApiAsync<object, dynamic>("Notification/PostOrderUpdate", data);
        }
    }
}
