﻿using System.Drawing.Imaging;
using System.IO;
using System.Threading.Tasks;
using AzureBakery.Sales.Model;
using System.Drawing;

namespace OrderProcessorRole.Labels
{
    public class LabelGenerator
    {
        public async Task<byte[]> GeBytes(Customer customer)
        {
            byte[] data = null;

            using (var b = new Bitmap(500, 250))
            {
                using (var g = Graphics.FromImage(b))
                {
                    DrawBackground(g);
                    DrawTitle(g, new PointF(0, 0));
                    DrawAddress(g, new PointF(0, 60), customer);
                    DrawPsudoBarCode(g, new PointF(250, 60));
                }

                using (var ms = new MemoryStream())
                {
                    b.Save(ms, ImageFormat.Jpeg);
                    await ms.FlushAsync();

                    data = ms.GetBuffer();
                    ms.Close();
                }
            }

            return data;
        }

        private void DrawBackground(Graphics g)
        {
            g.FillRectangle(new SolidBrush(Color.Yellow), new RectangleF(0, 0, 500, 250));
        }

        private void DrawTitle(Graphics g, PointF point)
        {
            var font = new Font(FontFamily.GenericSerif, 36, FontStyle.Regular);
            var textBrush = new SolidBrush(Color.Black);

            g.DrawString("Azure Bakery", font, textBrush, new PointF(point.X + 10, point.Y + 10));
        }

        private void DrawAddress(Graphics g, PointF point, Customer customer)
        {
            var font = new Font(FontFamily.GenericSerif, 16, FontStyle.Regular);
            var textBrush = new SolidBrush(Color.Black);

            g.DrawString(string.Format("{0} {1}", customer.FirstName, customer.LastName), font, textBrush, new PointF(point.X + 10, point.Y + 10));
            g.DrawString(customer.Address.HouseNumber.ToString(), font, textBrush, new PointF(point.X + 10, point.Y + 30));
            g.DrawString(customer.Address.Street, font, textBrush, new PointF(point.X + 10, point.Y + 50));
            g.DrawString(customer.Address.City, font, textBrush, new PointF(point.X + 10, point.Y + 70));
            g.DrawString(customer.Address.PostCode, font, textBrush, new PointF(point.X + 10, point.Y + 90));
        }

        private void DrawPsudoBarCode(Graphics g, PointF point)
        {
            var stripes = new float[] { 5, 10, 1, 3, 5, 6, 8, 10, 5, 10, 1, 3, 5, 6, 8, 10 };

            var start = new PointF(point.X + 10, point.Y + 10);
            var barBrush = new SolidBrush(Color.Black);

            var font = new Font(FontFamily.GenericSerif, 10, FontStyle.Regular);
            var textBrush = new SolidBrush(Color.Black);

            foreach (var stripe in stripes)
            {
                g.FillRectangle(barBrush, start.X, start.Y, stripe, 100);

                g.DrawString(stripe.ToString(), font, textBrush, new PointF(start.X - 4, start.Y + 110));

                start.X += (7 + stripe);
            }
        }
    }
}
