﻿using Microsoft.IdentityModel.Clients.ActiveDirectory;
using Microsoft.WindowsAzure.MobileServices;
using Newtonsoft.Json.Linq;
using SupplyApp.Helpers;
using System;
using System.Threading.Tasks;

namespace SupplyApp.DataServices
{
    public abstract class DataServiceBase
    {
        private const string USER_ID = "USER_ID";
        private const string USER_TOKEN = "USER_TOKEN";

        private const string authority = "https://login.windows.net/azurebakery.onmicrosoft.com";
        private const string clientID = "01d4b54c-c7fc-4db5-b9a6-32e2be7a25d7";

        private const string azureUri = "https://azurebakerysupply.azure-mobile.net";

        private const string resourceURI = "https://azurebakerysupply.azure-mobile.net/login/aad";

#if DEBUG
        protected readonly static MobileServiceClient _mobileService = new MobileServiceClient(
            "http://localhost:58932/",
            "pVuVEbnHyytHlKGsaDPIiuXyShTCAd83"
            );
#else
        protected readonly static MobileServiceClient _mobileService = new MobileServiceClient(
            "https://azurebakerysupply.azure-mobile.net",
            "pVuVEbnHyytHlKGsaDPIiuXyShTCAd83"
            );
#endif

        protected static MobileServiceAuthenticationProvider _provider = MobileServiceAuthenticationProvider.WindowsAzureActiveDirectory;

        protected async Task<T> ExecuteAuthenticated<T>(Func<Task<T>> t, int retries = 1)
        {
            int retry = 0;
            T retVal = default(T);

            while (retry < retries)
            {
                // If we have no current user, login
                if (_mobileService.CurrentUser == null)
                {
                    // If login fails return default
                    if (!await Login())
                        return retVal;
                }

                // Try and execute task
                try
                {
                    retVal = await t();
                    break;
                }
                catch (InvalidOperationException ioex)
                {
                    // If task has failed because it was unauthorised try again
                    if (ioex.Message == "Error: Unauthorized")
                    {
                        _mobileService.CurrentUser = null;
                    }

                    retry++;
                }
            }

            return retVal;
        }

        protected async Task ExecuteAuthenticated(Func<Task> t, int retries = 1)
        {
            int retry = 0;

            while (retry < retries)
            {
                // If we have no current user, login
                if (_mobileService.CurrentUser == null)
                {
                    // If login fails return
                    if (!await Login())
                        return;
                }

                // Try and execute task
                try
                {
                    await t();
                    break;
                }
                catch (InvalidOperationException ioex)
                {
                    // If task has failed because it was unauthorised try again
                    if (ioex.Message == "Error: Unauthorized")
                    {
                        _mobileService.CurrentUser = null;
                    }

                    retry++;
                }
            }
        }

        public static bool HasUserLoggedIn()
        {
            var userId = StorageHelper.GetSetting<string>(USER_ID, null);
            var userToken = StorageHelper.GetSetting<string>(USER_TOKEN, null);

            if (userId == null || userToken == null)
                return false;

            return true;
        }

        public static async Task<bool> Login()
        {
            // First have a look and see if we have the user's token
            var userId = StorageHelper.GetSetting<string>(USER_ID, null);
            var userToken = StorageHelper.GetSetting<string>(USER_TOKEN, null);

            bool success = true;

            if (userId != null && userToken != null)
            {
                // Create user and apply to client
                var user = new MobileServiceUser(userId);
                user.MobileServiceAuthenticationToken = userToken;
                _mobileService.CurrentUser = user;
            }
            else
            {
                try
                {
                    var ac = new AuthenticationContext(authority);
                    var ar = await ac.AcquireTokenAsync(resourceURI, clientID);
                    var payload = new JObject();
                    payload["access_token"] = ar.AccessToken;


                    MobileServiceUser user = null;
#if DEBUG
                    // Create temp client to loging to azure service, then pass user to local client
                    var client = new MobileServiceClient(azureUri, _mobileService.ApplicationKey);
                    user = await client.LoginAsync(_provider, payload);

                    // Swap user
                    _mobileService.CurrentUser = user;
#else
                    // Login
                    user = await _mobileService.LoginAsync(_provider, payload);
#endif

                    // Store credentials
                    StorageHelper.StoreSetting(USER_ID, user.UserId, true);
                    StorageHelper.StoreSetting(USER_TOKEN, user.MobileServiceAuthenticationToken, true);
                }
                catch (InvalidOperationException)
                {
                    // Something has gone wrong, most likely user cancelled by backing-out
                    success = false;
                }
            }

            return success;
        }


        public static void Logout()
        {
            _mobileService.Logout();

            // Clear credentials
            StorageHelper.StoreSetting(USER_ID, null, true);
            StorageHelper.StoreSetting(USER_TOKEN, null, true);
        }
    }
}
