﻿using System.Collections.Generic;
using Windows.Storage;

namespace SupplyApp.Helpers
{
    public class StorageHelper
    {
        /// <summary>
        /// Stored a setting, returns true if success
        /// </summary>
        /// <param name="key"></param>
        /// <param name="value"></param>
        /// <param name="overwrite"></param>
        /// <returns></returns>
        public static bool StoreSetting(string key, object value, bool overwrite)
        {
            if (overwrite && ApplicationData.Current.LocalSettings.Values.ContainsKey(key))
            {
                ApplicationData.Current.LocalSettings.Values[key] = value;
                return true;
            }
            else if (!ApplicationData.Current.LocalSettings.Values.ContainsKey(key))
            {
                ApplicationData.Current.LocalSettings.Values.Add(new KeyValuePair<string, object>(key, value));
                return true;
            }

            return false;
        }

        /// <summary>
        /// Get a setting from storage, returns default value if it does not exist
        /// </summary>
        /// <typeparam name="T"></typeparam>
        /// <param name="key"></param>
        /// <returns></returns>
        public static T GetSetting<T>(string key)
        {
            if (ApplicationData.Current.LocalSettings.Values.ContainsKey(key))
            {
                return (T)ApplicationData.Current.LocalSettings.Values[key];
            }

            return default(T);
        }

        public static T GetSetting<T>(string key, T defaultVal)
        {
            if (ApplicationData.Current.LocalSettings.Values.ContainsKey(key))
            {
                return (T)ApplicationData.Current.LocalSettings.Values[key];
            }

            return defaultVal;
        }

        public static void RemoveSetting(string key)
        {
            ApplicationData.Current.LocalSettings.Values.Remove(key);
        }
    }
}
