using System.Collections.ObjectModel;
using GalaSoft.MvvmLight;
using GalaSoft.MvvmLight.Command;
using Supply.Model;
using SupplyApp.DataServices;
using AzureBakery.Sales.Model;
using SupplyApp.Helpers;

namespace SupplyApp.ViewModel
{
    public class MainViewModel : ViewModelBase
    {
        private IDataService _dataService;
        private readonly ObservableCollection<OrderViewModel> _orders = null;

        private RelayCommand<OrderViewModel> _dispatchOrderCommand = null;

        public ObservableCollection<OrderViewModel> Orders
        {
            get { return this._orders; }
        }

        public RelayCommand<OrderViewModel> DispatchOrderCommand
        {
            get { return this._dispatchOrderCommand; }
        }

        public MainViewModel(IDataService dataService)
        {
            if (IsInDesignMode)
            {
                // Code runs in Blend --> create design time data.
            }
            else
            {
                this._dataService = dataService;

                this._orders = new ObservableCollection<OrderViewModel>();

                this.CreateCommands();
                this.InitializeData();
            }
        }

        private void CreateCommands()
        {
            this._dispatchOrderCommand = new RelayCommand<OrderViewModel>((o) =>
            {
                var order = o.Order.Clone();
                order.Status = OrderStatus.ReadyForDispatch.ToString();

                this._dataService.DispatchOrder(order);
            });
        }

        private async void InitializeData()
        {
            // Get orders
            var orders = await this._dataService.GetOrders();
            foreach (var o in orders)
                this._orders.Add(new OrderViewModel(o));

            foreach (var order in this._orders)
            {
                // Load barcode
                var data = await this._dataService.GetBarcode(order.Reference);
                order.Barcode = Imaging.GetBitmapImage(data);
            }
        }
    }
}