﻿using System;
using System.Threading.Tasks;
using AzureBakery.Sales.Model;
using Microsoft.ServiceBus;
using Microsoft.ServiceBus.Messaging;
using Supply.Model;

namespace SupplyMobileService.Services
{
    public class MessagingService
    {
        private readonly TopicClient _topicClient = null;
        private const string _topicName = "Order";
        private const string _subscriptionName = "SupplyServiceSubscription";

        public MessagingService()
        {
            this._topicClient = TopicClient.Create(_topicName);
        }

        public async Task CreateSubscriptionAsync()
        {
            var namespaceManager = NamespaceManager.Create();

            // Look for topic
            if (!namespaceManager.TopicExists(_topicName))
                return;

            var topic = await namespaceManager.GetTopicAsync(_topicName);

            if (!(await namespaceManager.SubscriptionExistsAsync(_topicName, _subscriptionName)))
            {
                await namespaceManager.CreateSubscriptionAsync(_topicName, _subscriptionName);
            }
        }

        public async Task DispatchOrder(OrderEntity order, int retries = 0)
        {
            var salesOrder = new Order()
            {
                Id = order.Id,
                Status = OrderStatus.Dispatched,
                Reference = order.PartitionKey
            };

            var message = new BrokeredMessage(salesOrder);

            message.Properties["Status"] = "Dispatched";
            message.MessageId = Guid.NewGuid().ToString();

            await this.SendMessageAsync(message, retries);
        }

        private async Task SendMessageAsync(BrokeredMessage message, int retries = 0)
        {
            var retry = 0;

            while (true)
            {
                try
                {
                    await this._topicClient.SendAsync(message);
                    break;
                }
                catch (MessagingException e)
                {
                    if (!e.IsTransient)
                        throw;
                    else
                        retry++;
                }

                if (retry > retries)
                    break;

                // Back-off for retry
                await Task.Delay(3000);
            }
        }
    }
}