﻿using Microsoft.IdentityModel.Clients.ActiveDirectory;
using System;
using System.Configuration;
using System.Diagnostics;
using System.Net;

namespace AzureBakery.Production.ManagementApplication.Services
{
    public abstract class AzureAdAuthBase
    {
        protected AuthenticationResult Token = null;

        protected readonly string ServiceUri = null;

        protected AzureAdAuthBase()
        {
            this.ServiceUri = ConfigurationManager.AppSettings["serviceUri"];
#if DEBUG
            // This will accept temp SSL certificates
            ServicePointManager.ServerCertificateValidationCallback += (se, cert, chain, sslerror) => true;
#endif
        }

        protected bool Login()
        {
            // Our AD Tenant domain name
            var tenantId = ConfigurationManager.AppSettings["ida:Tenant"];

            // Web API resource ID (The resource we want to use)
            var resourceId = ConfigurationManager.AppSettings["ida:Audience"];

            // Client App CLIENT ID (The ID of the AD app for this client application)
            var clientId = ConfigurationManager.AppSettings["ida:ClientID"]; 

            // Callback URI
            var callback = new Uri(ConfigurationManager.AppSettings["ida:CallbackUri"]);

            var authContext = new AuthenticationContext(string.Format("https://login.windows.net/{0}", tenantId));

            if(this.Token == null)
            {
                // See if we have a cached token
                var token = Properties.Settings.Default.Token;
                if (!string.IsNullOrWhiteSpace(token))
                    this.Token = AuthenticationResult.Deserialize(token);
            }
            
            if (this.Token == null)
            {
                try
                {
                    // Acquire fresh token - this will get user to login                
                    this.Token = authContext.AcquireToken(resourceId, clientId, callback);
                }
                catch(Exception ex)
                {
                    Debug.WriteLine(ex.ToString());

                    return false;
                }
            }
            else if(this.Token.ExpiresOn < DateTime.UtcNow)
            {
                // Refresh existing token this will not require login
                this.Token = authContext.AcquireTokenByRefreshToken(this.Token.RefreshToken, clientId);
            }          

            if (this.Token != null && this.Token.ExpiresOn > DateTime.UtcNow)
            {
                // Store token
                Properties.Settings.Default.Token = this.Token.Serialize(); // This should be encrypted
                Properties.Settings.Default.Save();

                return true;
            }

            // Clear token
            this.Token = null;

            Properties.Settings.Default.Token = null;
            Properties.Settings.Default.Save();

            return false;
        }
    }
}
