﻿using AzureBakery.Production.ManagementApplication.Services.Interfaces;
using AzureBakery.Production.Model;
using Microsoft.AspNet.SignalR.Client;
using System;
using System.Threading.Tasks;

namespace AzureBakery.Production.ManagementApplication.Services
{
    public class ManagementService : AzureAdAuthBase, IManagementService
    {
        private IHubProxy _proxy = null;

        public event EventHandler<Order> OrderUpdated;
        public event EventHandler<Batch> BatchUpdated;

        public ManagementService()
        {

        }

        public async Task Register()
        {
            // Login using AD OAuth
            if (!this.Login())
                return;

            // Get header from auth token
            var authHeader = this.Token.CreateAuthorizationHeader();

            // Create hub proxy and add auth token
            var cnString = string.Format("{0}signalr", base.ServiceUri);
            var hubConnection = new HubConnection(cnString, useDefaultUrl: false);
            this._proxy = hubConnection.CreateHubProxy("managementHub");
            hubConnection.Headers.Add("Authorization", authHeader);

            // Register for order updates
            this._proxy.On<Order>("updateOrder", order =>
            {
                this.OnOrderUpdated(order);
            });


            // Register for batch updates
            this._proxy.On<Batch>("updateBatch", batch =>
            {
                this.OnBatchUpdated(batch);
            });


            // Start hub connection
            await hubConnection.Start();
        }

        public async Task<bool> UpdateOrder(Order order)
        {
            // Invoke updateOrder method on hub
            await this._proxy.Invoke<Order>("updateOrder", order).ContinueWith(task =>
            {
                return !task.IsFaulted;
            });

            return false;
        }

        public async Task<bool> UpdateBatch(Batch batch)
        {
            // Invoke updateBatch method on hub
            await this._proxy.Invoke<Batch>("updateBatch", batch).ContinueWith(task =>
            {
                return !task.IsFaulted;
            });

            return false;
        }

        private void OnOrderUpdated(Order order)
        {
            if (this.OrderUpdated != null)
                this.OrderUpdated(this, order);
        }

        private void OnBatchUpdated(Batch batch)
        {
            if (this.BatchUpdated != null)
                this.BatchUpdated(this, batch);
        }
    }
}
