﻿using CustomerPhoneApp.DataServices;
using GalaSoft.MvvmLight.Threading;
using Microsoft.Phone.Notification;
using Microsoft.WindowsAzure.Messaging;
using System;
using System.Threading.Tasks;

namespace CustomerPhoneApp.Helpers
{
    public class ChannelHelper
    {
        // Singleton instance
        public static readonly ChannelHelper Default = new ChannelHelper();

        // Holds the push channel that is created or found.
        private HttpNotificationChannel _pushChannel;

        // The name of our push channel.
        private readonly string CHANNEL_NAME = "AzureBakeryPushChannel";
        private readonly string HUB_NAME = "azurebakerycustomerhub";
        private readonly string CONNECTION_STRING = "Endpoint=sb://azurebakerycustomerhub-ns.servicebus.windows.net/;SharedAccessKeyName=ZumoManagementSasKey;SharedAccessKey=KX9kWXakI8JXIHlsRVtmsn2x3hs6hUMHMnW9w0+aFuk=";

        private ChannelHelper()
        {

        }

        public async Task SetupChannel()
        {
            try
            {
                bool attach = false;

                // Try to find the push channel
                if (this._pushChannel == null)
                {
                    attach = true;
                    this._pushChannel = HttpNotificationChannel.Find(CHANNEL_NAME);
                }

                // Check if user has enabled
                bool enabled = SettingsHelper.Default.IsPushEnabled;

                // If the channel was not found, then create a new connection to the push service.
                if (this._pushChannel == null && enabled)
                {
                    this._pushChannel = new HttpNotificationChannel(CHANNEL_NAME);
                    this.AttachEvents();
                    this._pushChannel.Open();

                    // Bind channel for Tile events.
                    this._pushChannel.BindToShellTile();

                    // Bind channel for Toast events
                    this._pushChannel.BindToShellToast();
                }
                // If channel was found but not required, close it
                else if (this._pushChannel != null && !enabled)
                {
                    await this.UnRegister();

                    this._pushChannel.Close();
                    this._pushChannel.Dispose();
                    this._pushChannel = null;
                }
                // Channel is found and needed so just attach
                else if (this._pushChannel != null && enabled && attach)
                    this.AttachEvents();
            }
            catch (Exception ex)
            {
                System.Diagnostics.Debug.WriteLine(ex.ToString());
            }

        }

        private void AttachEvents()
        {
            // Register for all the events before attempting to open the channel.
            this._pushChannel.ChannelUriUpdated += async (s, e) =>
            {
                // Register URI with service
                this.Register();
            };

            this._pushChannel.ErrorOccurred += (s, e) =>
            {
                System.Diagnostics.Debug.WriteLine(e.ToString());
            };
        }

        public void Register()
        {
            try
            {
            // Stuff onto UI thread because login interacts with UI
            DispatcherHelper.RunAsync(async ()  =>
            {
                // Register with service
                var service = new DataService();
                await service.RegisterChannel(this.GetChannelTag());

                // Register with hub
                var hub = new NotificationHub(this.HUB_NAME, this.CONNECTION_STRING);
                var result = await hub.RegisterNativeAsync(this._pushChannel.ChannelUri.AbsoluteUri, new string[] { this.GetChannelTag(), "news" });
            });
            }
            catch (Exception ex)
            {
                System.Diagnostics.Debug.WriteLine(ex.ToString());
            }
        }

        public async Task UnRegister()
        {
            try
            {
                // UnRegister with service
                var service = new DataService();
                await service.DeleteChannel();

                // UnRegister with hub
                var hub = new NotificationHub(this.HUB_NAME, this.CONNECTION_STRING);
                await hub.UnregisterAllAsync(this.GetChannelTag());
            }
            catch (Exception ex)
            {
                System.Diagnostics.Debug.WriteLine(ex.ToString());
            }
        }

        private string GetChannelTag()
        {
            var tag = StorageHelper.GetSetting<string>("ChannelTag");
            if (tag == null)
            {
                tag = Guid.NewGuid().ToString();
                StorageHelper.StoreSetting("ChannelTag", tag, true);
            }

            return tag;


        }
    }
}
