﻿using AzureBakery.Sales.CustomerWebsite.Models;
using System;
using System.Collections.Generic;
using System.Data.Entity;
using System.Diagnostics;
using System.Linq;
using System.Web;

namespace AzureBakery.Sales.CustomerWebsite.DataAccess
{
    public class Repository<T> where T : class
    {
        private readonly ApplicationDbContext _ctx = null;

        private DbSet<T> _dbSet { get; set; }

        public Repository(ApplicationDbContext ctx)
        {
            this._ctx = ctx;
            this._dbSet = this._ctx.Set<T>();
        }        

        public IQueryable<T> GetAll()
        {
            Trace.TraceInformation("{0} Repository GetAll Start", typeof(T));

            IQueryable<T> entities = null;

            try
            {
                entities = this._dbSet;
            }
            catch(Exception ex)
            {
                Trace.TraceError("{0} Repository GetAll Exception: {1}", typeof(T), ex);

                throw;
            }

            Trace.TraceInformation("{0} Repository GetAll End", typeof(T));

            return entities;
        }

        public virtual T GetById(int id)
        {
            Trace.TraceInformation("{0} Repository GetById Start", typeof(T));

            T entity = null;

            try
            {
                entity = this._dbSet.Find(id);
            }
            catch (Exception ex)
            {
                Trace.TraceError("{0} Repository GetById Exception: {1}", typeof(T), ex);

                throw;
            }

            Trace.TraceInformation("{0} Repository GetById End", typeof(T));

            return entity;
        }

        public void Add(T entity)
        {
            Trace.TraceInformation("{0} Repository Add Start", typeof(T));

            try
            {
                var dbEntityEntry = this._ctx.Entry(entity);

                if (dbEntityEntry.State != EntityState.Detached)
                {
                    dbEntityEntry.State = EntityState.Added;
                }
                else
                {
                    this._dbSet.Add(entity);
                }
            }
            catch (Exception ex)
            {
                Trace.TraceError("{0} Repository Add Exception: {1}", typeof(T), ex);

                throw;
            }

            Trace.TraceInformation("{0} Repository Add End", typeof(T));
        }

        public void Update(T entity)
        {
            Trace.TraceInformation("{0} Repository Update Start", typeof(T));

            try
            {
                var dbEntityEntry = this._ctx.Entry(entity);

                if (dbEntityEntry.State == EntityState.Detached)
                {
                    this._dbSet.Attach(entity);
                }

                dbEntityEntry.State = EntityState.Modified;
            }
            catch (Exception ex)
            {
                Trace.TraceError("{0} Repository Update Exception: {1}", typeof(T), ex);

                throw;
            }

            Trace.TraceInformation("{0} Repository Update End", typeof(T));
        }

        public void Delete(T entity)
        {
            Trace.TraceInformation("{0} Repository Delete Start", typeof(T));

            try
            {
                var dbEntityEntry = this._ctx.Entry(entity);

                if (dbEntityEntry.State != EntityState.Deleted)
                {
                    dbEntityEntry.State = EntityState.Deleted;
                }
                else
                {
                    this._dbSet.Attach(entity);
                    this._dbSet.Remove(entity);
                }
            }
            catch (Exception ex)
            {
                Trace.TraceError("{0} Repository Delete Exception: {1}", typeof(T), ex);

                throw;
            }

            Trace.TraceInformation("{0} Repository Delete End", typeof(T));
        }

        public void Delete(int id)
        {
            Trace.TraceInformation("{0} Repository Delete Start", typeof(T));

            try
            {
                var entity = this.GetById(id);

                if (entity != null)
                {
                    this.Delete(entity);
                }
            }
            catch (Exception ex)
            {
                Trace.TraceError("{0} Repository Delete Exception: {1}", typeof(T), ex);

                throw;
            }

            Trace.TraceInformation("{0} Repository Delete End", typeof(T));
        }        
    }
}