﻿using System;
using System.Configuration;
using System.Threading.Tasks;
using System.Web.Http;
using Microsoft.WindowsAzure.Mobile.Service;
using Microsoft.WindowsAzure.Mobile.Service.Security;
using Microsoft.WindowsAzure.Storage;

namespace SupplyMobileService.Controllers
{
    [AuthorizeLevel(AuthorizationLevel.User)]
    public class BarcodeController : ApiController
    {
        private readonly CloudStorageAccount _storageAccount;

        public ApiServices Services { get; set; }

        public BarcodeController()
        {
            // Retrieve the storage account from the connection string.
            this._storageAccount = CloudStorageAccount.Parse(ConfigurationManager.ConnectionStrings["StorageConnectionString"].ConnectionString);
        }

        // GET api/Barcode
        public async Task<byte[]> Get(string reference)
        {
            Services.Log.Info("BarcodeController - Patch Start");

            try
            {
                var blobClient = this._storageAccount.CreateCloudBlobClient();
                var container = blobClient.GetContainerReference("barcodes");
                var blobRef = container.GetBlockBlobReference(reference);

                await blobRef.FetchAttributesAsync();
                var buffer = new byte[blobRef.Properties.Length];
                await blobRef.DownloadToByteArrayAsync(buffer, 0);

                Services.Log.Info("BarcodeController - Patch Completed");

                return buffer;
            }
            catch (Exception ex)
            {
                Services.Log.Error("BarcodeController - Get Error", ex);

                throw;
            }
        }

    }
}
