﻿using System.Collections.Generic;
using System.Configuration;
using System.Reflection.Emit;
using System.Threading.Tasks;
using System.Web.UI.WebControls;
using AzureBakery.Sales.Model;
using Microsoft.WindowsAzure.Mobile.Service;
using Microsoft.WindowsAzure.Mobile.Service.Security;
using System.Web.Http;
using Microsoft.WindowsAzure.Storage;
using Microsoft.WindowsAzure.Storage.Table;
using Supply.Model;
using SupplyMobileService.Services;

namespace SupplyMobileService.Controllers
{
    [AuthorizeLevel(AuthorizationLevel.User)]
    public class OrderController : ApiController
    {
        private readonly CloudStorageAccount _storageAccount;

        public ApiServices Services { get; set; }

        public OrderController()
        {
            // Retrieve the storage account from the connection string.
            this._storageAccount = CloudStorageAccount.Parse(ConfigurationManager.ConnectionStrings["StorageConnectionString"].ConnectionString);
        }

        // GET api/Orders
        public IEnumerable<OrderEntity> Get()
        {
            Services.Log.Info("OrderController - Get Start");

            try
            {
                var tableClient = _storageAccount.CreateCloudTableClient();

                var table = tableClient.GetTableReference("orders");

                var query = new TableQuery<OrderEntity>()
                    .Where(TableQuery.GenerateFilterCondition("Status", QueryComparisons.Equal,
                    //OrderStatus.ReadyForDispatch.ToString()));
                        OrderStatus.Open.ToString()));

                var data = table.ExecuteQuery(query);

                Services.Log.Info("OrderController - Get Completed");

                return data;
            }
            catch (System.Exception ex)
            {
                Services.Log.Error("OrderController - Get Error", ex);

                throw;
            }
        }

        public async Task Put([FromBody] OrderEntity entity)
        {
            Services.Log.Info("OrderController - Put Start");

            try
            {
                // Get orders table
                var tableClient = _storageAccount.CreateCloudTableClient();
                var table = tableClient.GetTableReference("orders");

                // Update entity
                var updateOp = TableOperation.Replace(entity);
                var updateResult = await table.ExecuteAsync(updateOp);

                // Send to service bus
                var messaging = new MessagingService();
                await messaging.CreateSubscriptionAsync();
                await messaging.DispatchOrder(entity);

                Services.Log.Info("OrderController - Put Completed");
            }
            catch (System.Exception ex)
            {
                Services.Log.Error("OrderController - Put Error", ex);

                throw;
            }
        }
    }
}
