﻿using AzureBakery.Sales.CustomerWebsite.Models;
using AzureBakery.Sales.Model;
using System;
using System.Collections.Generic;
using System.Linq;
using System.Web;
using System.Web.Mvc;
using Microsoft.AspNet.Identity;
using System.Data.Entity;

namespace AzureBakery.Sales.CustomerWebsite.Controllers
{
    public class ProductController : Controller
    {
        private readonly ApplicationDbContext _ctx = new ApplicationDbContext();

        //
        // GET: /Product/
        public ActionResult Index(ProductType productType)
        {
            var vm = new ProductsViewModel();
            vm.Title = productType.ToString();
            vm.ProductType = productType;
            vm.Products = this._ctx.Products
                .Where(p => p.ProductType == productType &&
                p.IsAvailable);

            return View(vm);
        }

        [Authorize]
        public ActionResult AddToOrder(int id)
        {
            // Get customer details
            var uid = User.Identity.GetUserId();

            var customer = this._ctx.Users
                .Include(u => u.Customer)
                .Single(u => u.Id == uid).Customer;

            // Try and find order 
            Order order = this._ctx.Orders
                .Include(o => o.Items.Select(i => i.Product))
                .SingleOrDefault(o => o.Customer.Id == customer.Id && o.Status == OrderStatus.Open);

            if (order == null)
            {
                order = new Order();
                order.Customer = customer;
                this._ctx.Orders.Add(order);
            }

            // Look for OrderItem
            OrderItem item = order.Items.SingleOrDefault(i => i.Product.Id == id);
            if (item == null)
            {
                item = new OrderItem();
                item.Product = this._ctx.Products.Single(p => p.Id == id);
                order.Items.Add(item);
            }
            else
            {
                item.Quantity++;
            }

            // Save
            this._ctx.SaveChanges();

            return RedirectToAction("Index", new { productType = item.Product.ProductType });
        }
    }
}