﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Web;
using System.Web.Mvc;
using Microsoft.AspNet.Identity;
using System.Data.Entity;
using AzureBakery.Sales.CustomerWebsite.Models;
using AzureBakery.Sales.Model;

namespace AzureBakery.Sales.CustomerWebsite.Controllers
{
    [Authorize]
    public class OrderController : Controller
    {
        private readonly ApplicationDbContext _ctx = new ApplicationDbContext();

        public ActionResult Index()
        {
            // Get customer details
            var uid = User.Identity.GetUserId();

            var customer = this._ctx.Users
                .Include(u => u.Customer)
                .Single(u => u.Id == uid).Customer;

            // Try and find orders 
            var orders = this._ctx.Orders
                .Include(o => o.Customer)
                .Where(o => o.Customer.Id == customer.Id)
                .OrderByDescending(o => o.CreatedDate);

            var vm = new OrdersViewModel();
            vm.Title = "Orders";
            vm.Items = orders.Select(o => new OrderViewModel() { Id = o.Id, Reference = o.Reference, Status = o.Status, CreatedDate = o.CreatedDate, Order = o });

            return View(vm);
        }

        //
        // GET: /Order/
        public ActionResult Basket()
        {
            var order = this.GetOpenOrder();

            var vm = new BasketViewModel();
            if (order != null)
            { 
                vm.Title = string.Format("Order Reference: {0}", order.Reference);
                vm.Order = order;
                vm.Items = order.Items.Select(oi => new OrderItemViewModel() { Id = oi.Id, Name = oi.Product.Name, Quantity = oi.Quantity, Item = oi });
                vm.CreatedDate = order.CreatedDate;
                vm.Status = order.Status;
            }
            else
            {
                vm.Title = "You have nothing in your basket!";
            }

            return View(vm);
        }

        public ActionResult Delete(int id)
        {
            var item = this._ctx.OrderItems.SingleOrDefault(oi => oi.Id == id);

            this._ctx.OrderItems.Remove(item);

            this._ctx.SaveChanges();

            return RedirectToAction("Index");
        }

        public ActionResult Pay()
        {
            return View();
        }

        public ActionResult PayConfirm()
        {
            var order = this.GetOpenOrder();

            // At this point we would need to take a card payment or setup an invoice
            // But this isn't real so we'll order the item!

            // Update status
            order.Status = OrderStatus.New;
            this._ctx.SaveChanges();

            // Todo: Send to messagging middleware

            return View();
        }

        private Order GetOpenOrder()
        {
            // Get customer details
            var uid = User.Identity.GetUserId();

            var customer = this._ctx.Users
                .Include(u => u.Customer)
                .Single(u => u.Id == uid).Customer;

            // Try and find order 
            Order order = this._ctx.Orders
                .Include(o => o.Items.Select(i => i.Product))
                .Include(o => o.Customer)
                .SingleOrDefault(o => o.Customer.Id == customer.Id && o.Status == OrderStatus.Open);

            return order;
        }
    }
}