﻿using AzureBakery.Sales.CustomerWebsite.Models;
using AzureBakery.Sales.Model;
using System;
using System.Collections.Generic;
using System.Linq;
using System.Web;
using System.Web.Mvc;
using Microsoft.AspNet.Identity;

using AzureBakery.Sales.CustomerWebsite.DataAccess;
using AzureBakery.Sales.CustomerWebsite.Instrumentation;

namespace AzureBakery.Sales.CustomerWebsite.Controllers
{
    public class ProductController : Controller
    {
        private readonly ProductUoW _uow = new ProductUoW();

        //
        // GET: /Product/
        public ActionResult Index(ProductType productType)
        {
            CustomerWebsiteEvents.Log.ProductControllerGetProductsStarted();

            ViewResult vw = null;

            try
            {
                var vm = new ProductsViewModel();
                vm.Title = productType.ToString();
                vm.ProductType = productType;
                vm.Products = this._uow.Products
                    .GetAll()
                    .Where(p => p.ProductType == productType &&
                    p.IsAvailable);

                vw = View(vm);
            }
            catch (Exception ex)
            {
                CustomerWebsiteEvents.Log.ProductControllerGetProductsError(ex.ToString(), "Controller_Error");

                throw;
            }

            CustomerWebsiteEvents.Log.ProductControllerGetProductsEnded();

            return vw;
        }

        [Authorize]
        public ActionResult AddToOrder(int id)
        {
            CustomerWebsiteEvents.Log.ProductControllerAddProductToOrderStarted();

            OrderItem item = null;

            try
            {
                // Get customer details
                var uid = User.Identity.GetUserId();

                // Add to order
                item = this._uow.AddToOrder(id, uid);

                // Save
                this._uow.SaveChanges();
            }
            catch (Exception ex)
            {
                CustomerWebsiteEvents.Log.ProductControllerAddProductToOrderError(ex.ToString(), "Controller_Error");

                throw;
            }

            CustomerWebsiteEvents.Log.ProductControllerAddProductToOrderEnded();

            return RedirectToAction("Index", new { productType = item.Product.ProductType });
        }
    }
}