﻿using AzureBakery.Sales.CustomerWebsite.Instrumentation;
using Microsoft.Practices.EnterpriseLibrary.SemanticLogging;
using System;
using System.Collections.Generic;
using System.Configuration;
using System.Diagnostics.Tracing;
using System.Linq;
using System.Web;
using System.Web.Mvc;
using System.Web.Optimization;
using System.Web.Routing;

namespace AzureBakery.Sales.CustomerWebsite
{
    public class MvcApplication : System.Web.HttpApplication
    {
        protected void Application_Start()
        {
            this.SetupListeners();

            CustomerWebsiteEvents.Log.ApplicationStarting();

            base.Error += MvcApplication_Error;

            AreaRegistration.RegisterAllAreas();
            FilterConfig.RegisterGlobalFilters(GlobalFilters.Filters);
            RouteConfig.RegisterRoutes(RouteTable.Routes);
            BundleConfig.RegisterBundles(BundleTable.Bundles);

            CustomerWebsiteEvents.Log.ApplicationStarted();
        }

        private void SetupListeners()
        {
            // Get log details from web config (these can be configured in website CONFIGURE tab)
            EventLevel logLevel = (EventLevel)Enum.Parse(typeof(EventLevel), ConfigurationManager.AppSettings["logLevel"]);
            var logAccountName = ConfigurationManager.AppSettings["logAccountName"];
            var logAccountKey = ConfigurationManager.AppSettings["logAccountKey"];
            var logTableName = ConfigurationManager.AppSettings["logTableName"];

            // Create listener and enable events
            var listener = new ObservableEventListener();
            listener.EnableEvents(CustomerWebsiteEvents.Log, logLevel, Keywords.All);

            // Build storage connection string
            var cnString = string.Format("DefaultEndpointsProtocol=https;AccountName={0};AccountKey={1}", logAccountName, logAccountKey);

            // Log listener to azure
            listener.LogToWindowsAzureTable("WindowsAzureListener", cnString, logTableName);

        }

        void MvcApplication_Error(object sender, EventArgs e)
        {
            CustomerWebsiteEvents.Log.ApplicationError(Server.GetLastError().ToString(), "MvcApplication_Error");
        }
    }
}
