﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Web;
using System.Web.Mvc;
using Microsoft.AspNet.Identity;
using System.Data.Entity;
using AzureBakery.Sales.CustomerWebsite.Models;
using AzureBakery.Sales.Model;
using System.Diagnostics;
using AzureBakery.Sales.CustomerWebsite.DataAccess;

namespace AzureBakery.Sales.CustomerWebsite.Controllers
{
    [Authorize]
    public class OrderController : Controller
    {
        private readonly OrderUoW _uow = new OrderUoW();

        public ActionResult Index()
        {
            Trace.TraceInformation("OrderController Index - Start");

            ViewResult vw = null;

            try
            {
                // Get customer details
                var uid = User.Identity.GetUserId();

                // Try and find orders 
                var orders = this._uow.GetCustomerOrders(uid);

                var vm = new OrdersViewModel();
                vm.Title = "Orders";
                vm.Items = orders.Select(o => new OrderViewModel() { Id = o.Id, Reference = o.Reference, Status = o.Status, CreatedDate = o.CreatedDate, Order = o });

                vw = View(vm);
            }
            catch (Exception ex)
            {
                Trace.TraceError("OrderController Index Error: {0}", ex);

                throw;
            }

            Trace.TraceInformation("OrderController Index - End");

            return vw;
        }

        //
        // GET: /Order/
        public ActionResult Basket()
        {
            Trace.TraceInformation("OrderController Basket - Start");

            ViewResult vw = null;

            try
            {
                var order = this.GetOpenOrder();

                var vm = new BasketViewModel();

                if (order != null)
                {
                    vm.Title = string.Format("Order Reference: {0}", order.Reference);
                    vm.Order = order;
                    vm.Items = order.Items.Select(oi => new OrderItemViewModel() { Id = oi.Id, Name = oi.Product.Name, Quantity = oi.Quantity, Item = oi });
                    vm.CreatedDate = order.CreatedDate;
                    vm.Status = order.Status;
                }
                else
                {
                    vm.Title = "You have nothing in your basket!";
                }

                vw = View(vm);
            }
            catch (Exception ex)
            {
                Trace.TraceError("OrderController Basket Error: {0}", ex);

                throw;
            }

            Trace.TraceInformation("OrderController Basket - End");

            return vw;
        }

        public ActionResult Delete(int id)
        {
            Trace.TraceInformation("OrderController Delete - Start");

            try
            {
                this._uow.OrderItems.Delete(id);

                this._uow.SaveChanges();

                Trace.TraceInformation("OrderController Delete - Start");
            }
            catch (Exception ex)
            {
                Trace.TraceError("OrderController Delete Error: {0}", ex);

                throw;
            }

            Trace.TraceInformation("OrderController Delete - End");

            return RedirectToAction("Basket");
        }

        public ActionResult Pay()
        {
            Trace.TraceInformation("OrderController Pay - Start");

            var vw = View();

            Trace.TraceInformation("OrderController Pay - End");

            return vw;
        }

        public ActionResult PayConfirm()
        {
            Trace.TraceInformation("OrderController PayConfirm - Start");

            ViewResult vw = null;

            try
            {
                var order = this.GetOpenOrder();

                // At this point we would need to take a card payment or setup an invoice
                // But this isn't real so we'll order the item!

                // Update status
                order.Status = OrderStatus.New;
                this._uow.SaveChanges();

                // Todo: Send to messagging middleware

                vw = View();
            }
            catch (Exception ex)
            {
                Trace.TraceError("OrderController PayConfirm Error: {0}", ex);

                throw;
            }

            Trace.TraceInformation("OrderController PayConfirm - End");

            return vw;
        }

        private Order GetOpenOrder()
        {
            Trace.TraceInformation("OrderController GetOpenOrder - Start");

            // Get customer details
            var uid = User.Identity.GetUserId();

            // Try and find order 
            Order order = this._uow.GetOpenOrder(uid);

            Trace.TraceInformation("OrderController GetOpenOrder - End");

            return order;
        }
    }
}