﻿using AzureBakery.Sales.CustomerWebsite.Models;
using AzureBakery.Sales.Model;
using System;
using System.Collections.Generic;
using System.Diagnostics;
using System.Linq;
using System.Web;
using System.Data.Entity;

namespace AzureBakery.Sales.CustomerWebsite.DataAccess
{
    public class ProductUoW : IDisposable
    {
        private readonly Repository<Product> _products = null;
        private readonly Repository<ApplicationUser> _users = null;
        private readonly Repository<Order> _orders = null;

        private readonly ApplicationDbContext _ctx = new ApplicationDbContext();

        public Repository<Product> Products { get { return this._products; } }
        public Repository<ApplicationUser> Users { get { return this._users; } }
        public Repository<Order> Orders { get { return this._orders; } }

        public ProductUoW()
        {
            this._products = new Repository<Product>(this._ctx);
            this._users = new Repository<ApplicationUser>(this._ctx);
            this._orders = new Repository<Order>(this._ctx);
        }

        public OrderItem AddToOrder(int id, string uid)
        {
            Trace.TraceInformation("ProductUoW AddToOrder Start");

            OrderItem item = null;

            try
            {
                var customer = this._users.GetAll()
                    .Include(u => u.Customer)
                    .Single(u => u.Id == uid).Customer;

                // Try and find order 
                Order order = this._orders.GetAll()
                    .Include(o => o.Items.Select(i => i.Product))
                    .SingleOrDefault(o => o.Customer.Id == customer.Id && o.Status == OrderStatus.Open);

                if (order == null)
                {
                    order = new Order();
                    order.Customer = customer;
                    this._orders.Add(order);
                }

                // Look for OrderItem
                item = order.Items.SingleOrDefault(i => i.Product.Id == id);
                if (item == null)
                {
                    item = new OrderItem();
                    item.Product = this._ctx.Products.Single(p => p.Id == id);
                    order.Items.Add(item);
                }
                else
                {
                    item.Quantity++;
                }
            }
            catch (Exception ex)
            {
                Trace.TraceError("ProductUoW AddToOrder Exception: {0}", ex);

                throw;
            }

            Trace.TraceInformation("ProductUoW AddToOrder End");

            return item;
        }

        public void SaveChanges()
        {
            Trace.TraceInformation("ProductUoW Save Start");

            try
            {
                this._ctx.SaveChanges();
            }
            catch (Exception ex)
            {
                Trace.TraceError("ProductUoW Save Exception: {0}", ex);

                throw;
            }

            Trace.TraceInformation("ProductUoW Save End");
        }

        public void Dispose()
        {
            this._ctx.Dispose();
        }
    }
}