﻿using OrderProcessorRole.DataAccess;
using System.Threading.Tasks;
using System.Linq;
using System.Data.Entity;
using AzureBakery.Production.Model;
using System;

namespace OrderProcessorRole.Business
{
    public class BatchProcessor
    {
        private readonly ApplicationDbContext _ctx = new ApplicationDbContext();

        public async Task Process()
        { 
            // Get order items with no batch
            var items = await _ctx.OrderItems.Where(oi => oi.Batch == null)
                .Include(oi => oi.Product)
                .ToListAsync();

            // Add each item to a batch
            foreach(var item in items)
            {
                int quantityPerBatch = item.Product.QuantityPerBatch;

                // First look for an incomplete batch
                var batch = await this._ctx.Batches.FirstOrDefaultAsync(b => b.Quantity < quantityPerBatch && b.Product.Id == item.Product.Id);

                int itemQuantityRemaining = item.Quantity;

                while (itemQuantityRemaining > 0)
                {
                    // If there is no batch create one
                    if (batch == null)
                    {
                        batch = new Batch()
                            {
                                CreatedDate = DateTime.Now,
                                Product = item.Product,
                                Status = BatchStatus.New
                            };

                        this._ctx.Batches.Add(batch);
                    }

                    int batchSpace = item.Product.QuantityPerBatch - batch.Quantity;

                    // If there is space add all items
                    if (batchSpace >= item.Quantity)
                    {
                        batch.Quantity += item.Quantity;
                        item.Batch = batch;
                        itemQuantityRemaining -= item.Quantity;
                        
                    }
                    else
                    {
                        batch.Quantity += batchSpace;
                        itemQuantityRemaining -= batchSpace;
                        item.Batch = batch;
                        batch = null; // Create a new batch next time round
                    }
                }

                await this._ctx.SaveChangesAsync();
            }            
        }
    }
}
