﻿using Microsoft.WindowsAzure;
using Microsoft.WindowsAzure.Storage;
using Microsoft.WindowsAzure.Storage.Queue;
using OrderProcessorRole.Business;
using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;

namespace OrderProcessorRole.Messaging
{
    public abstract class StorageQueueProcessorBase
    {
        private CloudQueue _batchQueue = null;

        private string _queueName = null;
        private string _cnString = null;
        private int _delay = 60000;

        public bool IsRunning { get; private set; }

        public StorageQueueProcessorBase(string queueName, string cnString)
        {
            this._queueName = queueName;
            this._cnString = cnString;

            this.CreateQueueClient();
        }

        public StorageQueueProcessorBase(string queueName, string cnString, int delay)
            : this(queueName, cnString)
        {
            this._delay = delay;

        }

        private void CreateQueueClient()
        {
            // Retrieve storage account from connection string
            var storageAccount = CloudStorageAccount.Parse(this._cnString);

            // Create a queue client to get refs from
            var queueClient = storageAccount.CreateCloudQueueClient();

            this._batchQueue = queueClient.GetQueueReference(this._queueName);
        }

        public async Task ProcessQueueAsync()
        {
            this.IsRunning = true;

            while (this.IsRunning)
            {
                bool delay = true;

                try
                {
                    var msg = await this._batchQueue.GetMessageAsync();
                    if (msg != null)
                    {
                        // Check the message is not expired which may occur after a failure and cause concurrent processing
                        if (DateTimeOffset.Now - msg.InsertionTime < TimeSpan.FromMinutes(10))
                        {
                            await this.Process();
                        }
                        else
                        {
                            // We have a message but it's expired so get next
                            delay = false;
                        }

                        // Delete message now we're finished with it
                        await this._batchQueue.DeleteMessageAsync(msg);
                    }
                }
                catch (Exception ex)
                {

                }

                // Wait for a minute
                if(delay)
                    await Task.Delay(this._delay);
            }
        }

        public void Stop()
        {
            this.IsRunning = false;
        }

        protected abstract Task Process();
    }
}
