using Microsoft.WindowsAzure.ServiceRuntime;
using OrderProcessorRole.Messaging;
using System;
using System.Diagnostics;
using System.Threading.Tasks;

namespace OrderProcessorRole
{
    public class WorkerRole : RoleEntryPoint
    {
        private OrderTopicProcessor _orderTopicProcessor = null;

        public override void Run()
        {
            Trace.TraceInformation("OrderProcessorRole.WorkerRole.Run - Begin");

            try
            {
                // WaitAll tasks will block Run until they have all completed, otherwise the role will recycle itself
                Task.WaitAll(
                    Task.Run(() => this._orderTopicProcessor.ProcessSubscriptionAsync())
                    );
            }
            catch (Exception ex)
            {
                Trace.TraceError("OrderProcessorRole.WorkerRole.Run - Error: {0}", ex);
            }
        }

        public override bool OnStart()
        {
            Trace.TraceInformation("OrderProcessorRole.WorkerRole.OnStart - Begin");

            try
            {
                // Create processors
                this._orderTopicProcessor = new OrderTopicProcessor();

                Trace.TraceInformation("OrderProcessorRole.WorkerRole.OnStart - End");

                return true;
            }
            catch (Exception ex)
            {
                Trace.TraceError("OrderProcessorRole.WorkerRole.OnStart - Error: {0}", ex);
            }

            return false;
        }


        public override void OnStop()
        {
            this._orderTopicProcessor.Stop();

            base.OnStop();
        }
    }
}
