﻿using OrderProcessorRole.DataAccess;
using System.Threading.Tasks;
using System.Linq;
using System.Data.Entity;
using AzureBakery.Production.Model;

namespace OrderProcessorRole.Business
{
    public class StockProcessor
    {
        private readonly ApplicationDbContext _ctx = new ApplicationDbContext();

        public async Task Process()
        {
            // Get order items with no ingredient allocation
            var items = await _ctx.OrderItems.Where(oi => !oi.IsStockAllocated)
                .Include(oi => oi.Product.Recipe)
                .ToListAsync();

            foreach (var item in items)
            {
                var recipeItems = await this._ctx.RecipeItems
                    .Include(r => r.Recipe)
                    .Include(r => r.Ingredient)
                    .Where(ri => ri.Recipe.Id == item.Product.Recipe.Id)
                    .ToListAsync();

                // Allocate ingredients
                foreach(var recipeItem in item.Product.Recipe.Items)
                {
                    recipeItem.Ingredient.StockQuantity -= recipeItem.Quantity;

                    if(recipeItem.Ingredient.StockQuantity < recipeItem.Ingredient.MinStock)
                    {
                        // We could send out an alert when stock gets too low
                    }
                }

                item.IsStockAllocated = true;
            }

            await this._ctx.SaveChangesAsync();
        }
    }
}
