using AzureBakery.Production.Model;
using OrderProcessorRole.DataAccess;
using System.Collections.Generic;
using System.Data.Entity.Migrations;

namespace OrderProcessorRole.Migrations
{


    internal sealed class Configuration : DbMigrationsConfiguration<ApplicationDbContext>
    {
        public Configuration()
        {
            AutomaticMigrationsEnabled = false;
        }

        protected override void Seed(OrderProcessorRole.DataAccess.ApplicationDbContext context)
        {
            // Ingredients
            var whiteFlour = new Ingredient("White Flour", 100.0m, 1000d, 100d);
            var brownFlour = new Ingredient("Brown Flour", 100.0m, 1000d, 100d);
            var wholemealFlour = new Ingredient("Wholemeal Flour", 100.0m, 1000d, 100d);

            var cornFlakes = new Ingredient("Corn Flakes", 100.0m, 1000d, 100d);
            var oats = new Ingredient("Oats", 100.0m, 1000d, 100d);
            var rasins = new Ingredient("Rasins", 100.0m, 1000d, 100d);
            var cherries = new Ingredient("Cherries", 100.0m, 1000d, 100d);

            var butter = new Ingredient("Butter", 100.0m, 1000d, 100d);
            var margarine = new Ingredient("Margarine", 100.0m, 1000d, 100d);
            var fat = new Ingredient("Fat", 100.0m, 1000d, 100d);

            var whiteSugar = new Ingredient("White Sugar", 100.0m, 1000d, 100d);
            var brownSugar = new Ingredient("Brown Sugar", 100.0m, 1000d, 100d);
            var icingSugar = new Ingredient("Icing Sugar", 100.0m, 1000d, 100d);
            var goldenSyrup = new Ingredient("Golden Syrup", 100.0m, 1000d, 100d);

            var cheese = new Ingredient("Cheese", 100.0m, 1000d, 100d);
            var potato = new Ingredient("Potato", 100.0m, 1000d, 100d);
            var onion = new Ingredient("Onion", 100.0m, 1000d, 100d);
            var carrot = new Ingredient("Carrot", 100.0m, 1000d, 100d);
            var mushroom = new Ingredient("Mushroom", 100.0m, 1000d, 100d);
            var jam = new Ingredient("Jam", 100.0m, 1000d, 100d);
            var chocolate = new Ingredient("Chocolate", 100.0m, 1000d, 100d);
            var chocolateChips = new Ingredient("Chocolate Chips", 100.0m, 1000d, 100d);

            var steak = new Ingredient("Steak", 100.0m, 1000d, 100d);
            var minceMeat = new Ingredient("Mince Meat", 100.0m, 1000d, 100d);
            var pork = new Ingredient("Pork", 100.0m, 1000d, 100d);
            var sausageMeat = new Ingredient("Sausage Meat", 100.0m, 1000d, 100d);
            var ham = new Ingredient("Ham", 100.0m, 1000d, 100d);
            var chicken = new Ingredient("Chicken", 100.0m, 1000d, 100d);
            var prawn = new Ingredient("Prawn", 100.0m, 1000d, 100d);
            var salad = new Ingredient("Salad", 100.0m, 1000d, 100d);
            var mayonaise = new Ingredient("Mayonaise", 100.0m, 1000d, 100d);
            var egg = new Ingredient("Egg", 100.0m, 1000d, 100d);
            var cress = new Ingredient("Cress", 100.0m, 1000d, 100d);

            var ginger = new Ingredient("Ginger", 100.0m, 1000d, 100d);
            var cinnamon = new Ingredient("Cinnamon", 100.0m, 1000d, 100d);
            var yeast = new Ingredient("Yeast", 100.0m, 1000d, 100d);

            var water = new Ingredient("Water", 1.0m, 1000d, 100d);

            var slicedBread = new Ingredient("Sliced Bread", 100.0m, 1000d, 100d);

            // Recipes
            var cheesePastyRecipe = new Recipe("Cheese Pasty Recipe")
            {
                Items = new List<RecipeItem>() { 
                new RecipeItem() { Ingredient = whiteFlour, Quantity = 250 },
                new RecipeItem() { Ingredient = cheese, Quantity = 250 },
                new RecipeItem() { Ingredient = margarine, Quantity = 250 }
            }
            };

            var cornishPastyRecipe = new Recipe("Cornish Pasty Recipe")
            {
                Items = new List<RecipeItem>() { 
                new RecipeItem() { Ingredient = whiteFlour, Quantity = 250 },
                new RecipeItem() { Ingredient = margarine, Quantity = 250 },
                new RecipeItem() { Ingredient = minceMeat, Quantity = 50 },
                new RecipeItem() { Ingredient = potato, Quantity = 50 },
                new RecipeItem() { Ingredient = onion, Quantity = 50 },
                new RecipeItem() { Ingredient = carrot, Quantity = 50 },
            }
            };

            var steakPastyRecipe = new Recipe("Steak Pasty Recipe")
            {
                Items = new List<RecipeItem>() { 
                new RecipeItem() { Ingredient = whiteFlour, Quantity = 250 },
                new RecipeItem() { Ingredient = margarine, Quantity = 250 },
                new RecipeItem() { Ingredient = steak, Quantity = 50 },
            }
            };

            var chickenMushroomPastyRecipe = new Recipe("Chicken & Mushroom Pasty Recipe")
            {
                Items = new List<RecipeItem>() { 
                new RecipeItem() { Ingredient = whiteFlour, Quantity = 250 },
                new RecipeItem() { Ingredient = margarine, Quantity = 250 },
                new RecipeItem() { Ingredient = chicken, Quantity = 50 },
                new RecipeItem() { Ingredient = mushroom, Quantity = 50 },
            }
            };

            var porkPieRecipe = new Recipe("Pork Pie Recipe")
            {
                Items = new List<RecipeItem>() { 
                new RecipeItem() { Ingredient = whiteFlour, Quantity = 250 },
                new RecipeItem() { Ingredient = fat, Quantity = 250 },
                new RecipeItem() { Ingredient = pork, Quantity = 50 },
            }
            };

            var sausageRoleRecipe = new Recipe("Sausage Roll Recipe")
            {
                Items = new List<RecipeItem>() { 
                new RecipeItem() { Ingredient = whiteFlour, Quantity = 250 },
                new RecipeItem() { Ingredient = fat, Quantity = 250 },
                new RecipeItem() { Ingredient = sausageMeat, Quantity = 50 },
            }
            };

            var donutRecipe = new Recipe("Donut Recipe")
            {
                Items = new List<RecipeItem>() { 
                new RecipeItem() { Ingredient = whiteFlour, Quantity = 250 },
                new RecipeItem() { Ingredient = whiteSugar, Quantity = 50 },
            }
            };

            var jamDonutRecipe = new Recipe("Jam Donut Recipe")
            {
                Items = new List<RecipeItem>() { 
                new RecipeItem() { Ingredient = whiteFlour, Quantity = 250 },
                new RecipeItem() { Ingredient = whiteSugar, Quantity = 50 },
                new RecipeItem() { Ingredient = jam, Quantity = 50 },
            }
            };

            var cupCakeRecipe = new Recipe("Cup Cake Recipe")
            {
                Items = new List<RecipeItem>() { 
                new RecipeItem() { Ingredient = whiteFlour, Quantity = 250 },
                new RecipeItem() { Ingredient = whiteSugar, Quantity = 50 },
                new RecipeItem() { Ingredient = icingSugar, Quantity = 50 },
                new RecipeItem() { Ingredient = butter, Quantity = 50 },
            }
            };

            var fruitCakeRecipe = new Recipe("Fruit Cake Recipe")
            {
                Items = new List<RecipeItem>() { 
                new RecipeItem() { Ingredient = whiteFlour, Quantity = 250 },
                new RecipeItem() { Ingredient = whiteSugar, Quantity = 50 },
                new RecipeItem() { Ingredient = rasins, Quantity = 50 },
                new RecipeItem() { Ingredient = cherries, Quantity = 50 },
                new RecipeItem() { Ingredient = butter, Quantity = 50 },
            }
            };

            var fairyCakeRecipe = new Recipe("Fairy Cake Recipe")
            {
                Items = new List<RecipeItem>() { 
                new RecipeItem() { Ingredient = whiteFlour, Quantity = 250 },
                new RecipeItem() { Ingredient = whiteSugar, Quantity = 50 },
                new RecipeItem() { Ingredient = icingSugar, Quantity = 50 },
                new RecipeItem() { Ingredient = cinnamon, Quantity = 5 },
                new RecipeItem() { Ingredient = butter, Quantity = 50 },
            }
            };

            var chocolateCrispieRecipe = new Recipe("Chocolate Crispie Recipe")
            {
                Items = new List<RecipeItem>() { 
                new RecipeItem() { Ingredient = cornFlakes, Quantity = 250 },
                new RecipeItem() { Ingredient = whiteSugar, Quantity = 50 },
                new RecipeItem() { Ingredient = chocolate, Quantity = 50 },
                new RecipeItem() { Ingredient = butter, Quantity = 50 },
            }
            };

            var chocolateChipCookieRecipe = new Recipe("Chocolate Chip Cookie Recipe")
            {
                Items = new List<RecipeItem>() { 
                new RecipeItem() { Ingredient = whiteFlour, Quantity = 250 },
                new RecipeItem() { Ingredient = whiteSugar, Quantity = 50 },
                new RecipeItem() { Ingredient = chocolateChips, Quantity = 50 },
                new RecipeItem() { Ingredient = butter, Quantity = 50 },
            }
            };

            var gingerBreadManRecipe = new Recipe("Gingerbread Man Recipe")
            {
                Items = new List<RecipeItem>() { 
                new RecipeItem() { Ingredient = whiteFlour, Quantity = 250 },
                new RecipeItem() { Ingredient = whiteSugar, Quantity = 50 },
                new RecipeItem() { Ingredient = butter, Quantity = 50 },
                new RecipeItem() { Ingredient = ginger, Quantity = 5 },
            }
            };

            var flapjackRecipe = new Recipe("Flapjack Recipe")
            {
                Items = new List<RecipeItem>() { 
                new RecipeItem() { Ingredient = oats, Quantity = 250 },
                new RecipeItem() { Ingredient = brownSugar, Quantity = 50 },
                new RecipeItem() { Ingredient = goldenSyrup, Quantity = 50 },
                new RecipeItem() { Ingredient = butter, Quantity = 50 },
                new RecipeItem() { Ingredient = ginger, Quantity = 5 },
            }
            };

            var shortbreadRecipe = new Recipe("Shortbread Recipe")
            {
                Items = new List<RecipeItem>() { 
                new RecipeItem() { Ingredient = whiteFlour, Quantity = 250 },
                new RecipeItem() { Ingredient = whiteSugar, Quantity = 50 },
                new RecipeItem() { Ingredient = butter, Quantity = 50 },
            }
            };

            var whiteLoafRecipe = new Recipe("White Loaf Recipe")
            {
                Items = new List<RecipeItem>() { 
                new RecipeItem() { Ingredient = whiteFlour, Quantity = 250 },
                new RecipeItem() { Ingredient = whiteSugar, Quantity = 50 },
                new RecipeItem() { Ingredient = yeast, Quantity = 5 },
                new RecipeItem() { Ingredient = water, Quantity = 100 },
            }
            };

            var brownLoafRecipe = new Recipe("Brown Loaf Recipe")
            {
                Items = new List<RecipeItem>() { 
                new RecipeItem() { Ingredient = brownFlour, Quantity = 250 },
                new RecipeItem() { Ingredient = whiteSugar, Quantity = 50 },
                new RecipeItem() { Ingredient = yeast, Quantity = 5 },
                new RecipeItem() { Ingredient = water, Quantity = 100 },
            }
            };

            var wholemealLoafRecipe = new Recipe("Wholemeal Loaf Recipe")
            {
                Items = new List<RecipeItem>() { 
                new RecipeItem() { Ingredient = wholemealFlour, Quantity = 250 },
                new RecipeItem() { Ingredient = whiteSugar, Quantity = 50 },
                new RecipeItem() { Ingredient = yeast, Quantity = 5 },
                new RecipeItem() { Ingredient = water, Quantity = 100 },
            }
            };

            var frenchStickRecipe = new Recipe("French Stick Recipe")
            {
                Items = new List<RecipeItem>() { 
                new RecipeItem() { Ingredient = whiteFlour, Quantity = 250 },
                new RecipeItem() { Ingredient = whiteSugar, Quantity = 50 },
                new RecipeItem() { Ingredient = yeast, Quantity = 5 },
                new RecipeItem() { Ingredient = water, Quantity = 100 },
            }
            };

            var baguetteRecipe = new Recipe("Baguette Recipe")
            {
                Items = new List<RecipeItem>() { 
                new RecipeItem() { Ingredient = whiteFlour, Quantity = 250 },
                new RecipeItem() { Ingredient = whiteSugar, Quantity = 50 },
                new RecipeItem() { Ingredient = yeast, Quantity = 5 },
                new RecipeItem() { Ingredient = water, Quantity = 100 },
            }
            };

            var cheeseSandwichRecipe = new Recipe("Cheese Sandwich Recipe")
            {
                Items = new List<RecipeItem>() { 
                new RecipeItem() { Ingredient = slicedBread, Quantity = 2 },
                new RecipeItem() { Ingredient = cheese, Quantity = 50 },
            }
            };

            var cheeseSaladSandwichRecipe = new Recipe("Cheese Salad Sandwich Recipe")
            {
                Items = new List<RecipeItem>() { 
                new RecipeItem() { Ingredient = slicedBread, Quantity = 2 },
                new RecipeItem() { Ingredient = cheese, Quantity = 50 },
                new RecipeItem() { Ingredient = salad, Quantity = 50 },
            }
            };

            var hamSandwichRecipe = new Recipe("Ham Sandwich Recipe")
            {
                Items = new List<RecipeItem>() { 
                new RecipeItem() { Ingredient = slicedBread, Quantity = 2 },
                new RecipeItem() { Ingredient = ham, Quantity = 50 },
            }
            };

            var hamSaladSandwichRecipe = new Recipe("Ham Salad Sandwich Recipe")
            {
                Items = new List<RecipeItem>() { 
                new RecipeItem() { Ingredient = slicedBread, Quantity = 2 },
                new RecipeItem() { Ingredient = ham, Quantity = 50 },
                new RecipeItem() { Ingredient = salad, Quantity = 50 },
            }
            };

            var chickenSandwichRecipe = new Recipe("Chicken Sandwich Recipe")
            {
                Items = new List<RecipeItem>() { 
                new RecipeItem() { Ingredient = slicedBread, Quantity = 2 },
                new RecipeItem() { Ingredient = chicken, Quantity = 50 },
            }
            };

            var chickenSaladSandwichRecipe = new Recipe("Chicken Salad Sandwich Recipe")
            {
                Items = new List<RecipeItem>() { 
                new RecipeItem() { Ingredient = slicedBread, Quantity = 2 },
                new RecipeItem() { Ingredient = chicken, Quantity = 50 },
                new RecipeItem() { Ingredient = salad, Quantity = 50 },
            }
            };

            var prawnMayonaiseSandwichRecipe = new Recipe("Prawn Mayonaise Sandwich Recipe")
            {
                Items = new List<RecipeItem>() { 
                new RecipeItem() { Ingredient = slicedBread, Quantity = 2 },
                new RecipeItem() { Ingredient = prawn, Quantity = 50 },
                new RecipeItem() { Ingredient = mayonaise, Quantity = 50 },
            }
            };

            var eggCressSandwichRecipe = new Recipe("Egg & Cress Sandwich Recipe")
            {
                Items = new List<RecipeItem>() { 
                new RecipeItem() { Ingredient = slicedBread, Quantity = 2 },
                new RecipeItem() { Ingredient = egg, Quantity = 50 },
                new RecipeItem() { Ingredient = cress, Quantity = 50 },
            }
            };

            //  This method will be called after migrating to the latest version.
            context.Products.AddOrUpdate(
                p => p.Name,
                new Product("Cheese Pasty", ProductType.Pastries, 50) { Recipe = cheesePastyRecipe },
                new Product("Cornish Pasty", ProductType.Pastries, 50) { Recipe = cornishPastyRecipe },
                new Product("Steak Pasty", ProductType.Pastries, 50) { Recipe = steakPastyRecipe },
                new Product("Chicken & Mushroom Pasty", ProductType.Pastries, 50) { Recipe = chickenMushroomPastyRecipe },
                new Product("Pork Pie", ProductType.Pastries, 25) { Recipe = porkPieRecipe },
                new Product("Sausage Roll", ProductType.Pastries, 100) { Recipe = sausageRoleRecipe },
                new Product("Donut", ProductType.Cakes, 50) { Recipe = donutRecipe },
                new Product("Jam Donut", ProductType.Cakes, 50) { Recipe = jamDonutRecipe },
                new Product("Cup Cake", ProductType.Cakes, 50) { Recipe = cupCakeRecipe },
                new Product("Fruit Cake", ProductType.Cakes, 50) { Recipe = fruitCakeRecipe },
                new Product("Fairy Cake", ProductType.Cakes, 50) { Recipe = fairyCakeRecipe },
                new Product("Chocolate Crispie", ProductType.Cakes, 50) { Recipe = chocolateCrispieRecipe },
                new Product("Chocolate Chip Cookie", ProductType.Biscuits, 50) { Recipe = chocolateChipCookieRecipe },
                new Product("Gingerbread Man", ProductType.Biscuits, 50) { Recipe = gingerBreadManRecipe },
                new Product("Flapjack", ProductType.Biscuits, 50) { Recipe = flapjackRecipe },
                new Product("Shortbread", ProductType.Biscuits, 50) { Recipe = shortbreadRecipe },
                new Product("White Loaf", ProductType.Bread, 25) { Recipe = whiteLoafRecipe },
                new Product("Brown Loaf", ProductType.Bread, 25) { Recipe = brownLoafRecipe },
                new Product("Wholemeal Loaf", ProductType.Bread, 25) { Recipe = whiteLoafRecipe },
                new Product("French Stick", ProductType.Bread, 30) { Recipe = frenchStickRecipe },
                new Product("Baguette", ProductType.Bread, 30) { Recipe = baguetteRecipe },
                new Product("Cheese Sandwich", ProductType.Sandwiches, 20) { Recipe = cheeseSandwichRecipe },
                new Product("Cheese Salad Sandwich", ProductType.Sandwiches, 20) { Recipe = cheeseSaladSandwichRecipe },
                new Product("Ham Sandwich", ProductType.Sandwiches, 20) { Recipe = hamSandwichRecipe },
                new Product("Ham Salad Sandwich", ProductType.Sandwiches, 20) { Recipe = hamSaladSandwichRecipe },
                new Product("Chicken Sandwich", ProductType.Sandwiches, 20) { Recipe = chickenSandwichRecipe },
                new Product("Chicken Salad Sandwich", ProductType.Sandwiches, 20) { Recipe = chickenSaladSandwichRecipe },
                new Product("Prawn Mayonaise Sandwich", ProductType.Sandwiches, 20) { Recipe = prawnMayonaiseSandwichRecipe },
                new Product("Egg & Cress Sandwich", ProductType.Sandwiches, 20) { Recipe = eggCressSandwichRecipe }
                );
        }
    }
}
